# Speedcord
![GitHub last commit](https://img.shields.io/github/last-commit/tag-epic/speedcord)
![GitHub issues](https://img.shields.io/github/issues-raw/tag-epic/speedcord)
![GitHub pull requests](https://img.shields.io/github/issues-pr/tag-epic/speedcord)
![PyPI downloads](https://img.shields.io/pypi/dm/speedcord)
[![Discord support](https://img.shields.io/discord/759919164872982528)](https://discord.gg/yxrprWz)  
A simple discord API wrapper - without all the bullshit  
If you liked the library, feel free to leave a star!

## Installing
WARNING: Please pin the version in production. Things can break.  

```bash
pip3 install speedcord
```

## Usage
Check the examples directory to find a few examples  
